# project

## Fail on Policy Violation Severities
```
--detect.policy.check.fail.on.severities=ALL,NONE,BLOCKER,CRITICAL,MAJOR,MINOR,OK,TRIVIAL,UNSPECIFIED 
```

A comma\-separated list of policy violation severities that will fail Detect\. If this is set to NONE, Detect will not fail due to policy violations\. A value of ALL is equivalent to all of the other possible values except NONE\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|PolicyRuleSeverityType List|
|Default Value|NONE|
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|ALL, NONE, BLOCKER, CRITICAL, MAJOR, MINOR, OK, TRIVIAL, UNSPECIFIED|
|Strict|Yes|

## Fail on Policy Names with Violations
```
--detect.policy.check.fail.on.names
```

A comma\-separated list of policy names with a non\-zero number of violations that will fail Detect\.

If left unset, Detect will not fail due to violated policies of a certain name\. This property does not change the behavior of detect\.policy\.check\.fail\.on\.severities\.

|Details||
|---|---|
|Added|7\.12\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Project Description
```
--detect.project.description
```

If project description is specified, your project will be created with this description\.



|Details||
|---|---|
|Added|4\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Project Name
```
--detect.project.name
```

An override for the name to use for the Black Duck project\. If not supplied, Detect will attempt to use the tools to figure out a reasonable project name\. If that fails, the final part of the directory path where the inspection is taking place will be used\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Project Tier
```
--detect.project.tier
```

If a Black Duck project tier is specified, your project will be created with this tier\.



|Details||
|---|---|
|Added|3\.1\.0|
|Type|Optional Integer|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Version Name
```
--detect.project.version.name
```

An override for the version to use for the Black Duck project\. If not supplied, Detect will attempt to use the tools to figure out a reasonable version name\. If that fails, the current date will be used\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Version Nickname
```
--detect.project.version.nickname
```

If a project version nickname is specified, your project version will be created with this nickname\.



|Details||
|---|---|
|Added|5\.2\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Version Notes
```
--detect.project.version.notes
```

If project version notes are specified, your project version will be created with these notes\.



|Details||
|---|---|
|Added|3\.1\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Version Phase
```
--detect.project.version.phase=ARCHIVED,DEPRECATED,DEVELOPMENT,PLANNING,PRERELEASE,RELEASED 
```

An override for the Project Version phase\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|ProjectVersionPhaseType|
|Default Value|DEVELOPMENT|
|Comma Separated|No|
|Case Sensitive|Yes|
|Acceptable Values|ARCHIVED, DEPRECATED, DEVELOPMENT, PLANNING, PRERELEASE, RELEASED|
|Strict|Yes|

## Update Project Version
```
--detect.project.version.update=false
```

If set to true, will update the Project Version with the configured properties\. See detailed help for more information\.

When set to true, the following properties will be updated on the Project\. Project tier \(detect\.project\.tier\) and Project Level Adjustments \(detect\.project\.level\.adjustments\)\. The following properties will also be updated on the Version\.Version notes \(detect\.project\.version\.notes\), phase\(detect\.project\.version\.phase\), distribution\(detect\.project\.version\.distribution\)\.

|Details||
|---|---|
|Added|4\.0\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|

## Project Version License
```
--detect.project.version.license
```

An override for a Project Version's license\.



|Details||
|---|---|
|Added|7\.11\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
|Example|`Apache License 2.0`|


## Clone Project Version Name (Advanced)
```
--detect.clone.project.version.name
```

The name of the project version to clone this project version from\. Respects the given Clone Categories in detect\.project\.clone\.categories or as set on the Black Duck server\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Clone Latest Project Version (Advanced)
```
--detect.clone.project.version.latest=false
```

If set to true, detect will attempt to use the latest project version as the clone for this project\. The project must exist and have at least one version\.



|Details||
|---|---|
|Added|5\.6\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Scan Name (Advanced)
```
--detect.code.location.name
```

An override for the base name Detect will use for the scan \(codelocation\) it creates\. Detect appends a suffix to the base name that indicates the source \("scan" for the signature scanner, "gradle/bom" for the Gradle detector, etc\.\)\. If this property is set and multiple code locations are generated from the same source, Detect will also append an index to avoid name collisions\. When this property is set, detect\.project\.codelocation\.prefix and detect\.project\.codelocation\.suffix are ignored\.



|Details||
|---|---|
|Added|4\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Application ID (Advanced)
```
--detect.project.application.id
```

Sets the 'Application ID' project setting\.



|Details||
|---|---|
|Added|5\.2\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Project Group Name (Advanced)
```
--detect.project.group.name
```

Sets the 'Project Group' to assign the project to\. Must match exactly to an existing project group on Black Duck\.



|Details||
|---|---|
|Added|7\.8\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Custom Fields (Advanced)
```
--detect.custom.fields.project
```

A  list of custom fields with a label and comma\-separated value starting from index 0\. For each index, provide one label and one value\. For example, to set a custom field with label 'example' to 'one,two': \`detect\.custom\.fields\.project\[0\]\.label='example'\` and \`detect\.custom\.fields\.project\[0\]\.value='one,two'\`\. To set another field, use index 1\. Note that these will not show up in the detect configuration log\.

When assigning a value that contains a comma to a single\-value field such as a text field, append '\[0\]' to the end of the value property name\. For example, to set the value of the first field you are setting \('detect\.custom\.fields\.version\[0\]'\) to 'text1,text2', use 'detect\.custom\.fields\.version\[0\]\.value\[0\]=text1,text2'\.

|Details||
|---|---|
|Added|5\.6\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Custom Fields (Advanced)
```
--detect.custom.fields.version
```

A  list of custom fields with a label and comma\-separated value starting from index 0\. For each index, provide one label and one value\. For example , to set a custom field with label 'example' to 'one,two': \`detect\.custom\.fields\.version\[0\]\.label='example'\` and \`detect\.custom\.fields\.version\[0\]\.value='one,two'\`\. To set another field, use index 1\. Note that these will not show up in the detect configuration log\.

When assigning a value that contains a comma to a single\-value field such as a text field, append '\[0\]' to the end of the value property name\. For example, to set the value of the first field you are setting \('detect\.custom\.fields\.version\[0\]'\) to 'text1,text2', use 'detect\.custom\.fields\.version\[0\]\.value\[0\]=text1,text2'\.

|Details||
|---|---|
|Added|5\.6\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Clone Project Categories (Advanced)
```
--detect.project.clone.categories=ALL,NONE,COMPONENT_DATA,CUSTOM_FIELD_DATA,DEEP_LICENSE,LICENSE_TERM_FULFILLMENT,VERSION_SETTINGS,VULN_DATA 
```

The value of this property is used to set the 'Cloning' settings on created Black Duck projects\. If property detect\.project\.version\.update is set to true, the value of this property is used to set the 'Cloning' settings on updated Black Duck projects\.



|Details||
|---|---|
|Added|4\.2\.0|
|Type|ProjectCloneCategoriesType List|
|Default Value|COMPONENT\_DATA,VULN\_DATA,VERSION\_SETTINGS,CUSTOM\_FIELD\_DATA,LICENSE\_TERM\_FULFILLMENT|
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|ALL, NONE, COMPONENT\_DATA, CUSTOM\_FIELD\_DATA, DEEP\_LICENSE, LICENSE\_TERM\_FULFILLMENT, VERSION\_SETTINGS, VULN\_DATA|
|Strict|Yes|
    
## Scan Name Prefix (Advanced)
```
--detect.project.codelocation.prefix
```

A prefix to the name of the scans created by Detect\. Useful for running against the same projects on multiple machines\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Scan Name Suffix (Advanced)
```
--detect.project.codelocation.suffix
```

A suffix to the name of the scans created by Detect\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Unmap All Other Scans for Project (Advanced)
```
--detect.project.codelocation.unmap=false
```

If set to true, unmaps all other scans mapped to the project version produced by the current run of Detect\.



|Details||
|---|---|
|Added|4\.0\.0|
|Type|Boolean|
|Default Value|false|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Project User Groups (Advanced)
```
--detect.project.user.groups
```

A comma\-separated list of names of user groups to add to the project\.



|Details||
|---|---|
|Added|5\.4\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    |Example|`ProjectManagers,TechLeads`|

## Project Tags (Advanced)
```
--detect.project.tags
```

A comma\-separated list of tags to add to the project\. This property is not supported when using Synopsys Detect in offline mode\.



|Details||
|---|---|
|Added|5\.6\.0|
|Type|String List|
|Default Value||
|Comma Separated|Yes|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    |Example|`Critical`|

## Allow Project Level Adjustments (Advanced)
```
--detect.project.level.adjustments=true
```

Sets the component adjustments setting on the Black Duck project\.

Corresponds to the 'Always maintain component adjustments to all versions of this project' checkbox under 'Component Adjustments' on the Black Duck Project settings page\.

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Boolean|
|Default Value|true|
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Parent Project Name (Advanced)
```
--detect.parent.project.name
```

When a parent project and version name are specified, the created detect project will be added as a component to the specified parent project version\. The specified parent project and parent project version must exist on Black Duck\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Parent Project Version Name (Advanced)
```
--detect.parent.project.version.name
```

When a parent project and version name are specified, the created detect project will be added as a component to the specified parent project version\. The specified parent project and parent project version must exist on Black Duck\.



|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## Version Distribution (Advanced)
```
--detect.project.version.distribution=EXTERNAL,INTERNAL,OPENSOURCE,SAAS 
```

An override for the Project Version distribution



|Details||
|---|---|
|Added|3\.0\.0|
|Type|ProjectVersionDistributionType|
|Default Value|EXTERNAL|
|Comma Separated|No|
|Case Sensitive|Yes|
|Acceptable Values|EXTERNAL, INTERNAL, OPENSOURCE, SAAS|
|Strict|Yes|
    


## Aggregate BDIO File Name (Deprecated) 
```
--detect.bom.aggregate.name
```

If set, this will aggregate all the BOMs to create a single BDIO file with the filename provided\.



**DEPRECATED: This property is being removed\. Use detect\.bdio\.file\.name to control the name of the bdio file Detect generates\. Currently detect\.bdio\.file\.name has the same effects as this property\. In the future, Detect will always operate in SUBPROJECT aggregation mode regardless of how it is configured; detect\.bdio\.file\.name will only control the BDIO file name\. This property will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|3\.0\.0|
|Type|Optional String|
|Default Value||
|Comma Separated|No|
|Case Sensitive|No|
|Acceptable Values|Any|
|Strict|No|
    
## BDIO Aggregate Remediation Mode (Deprecated) 
```
--detect.bom.aggregate.remediation.mode=DIRECT,TRANSITIVE,SUBPROJECT 
```

If an aggregate BDIO file is being generated \(that is, property detect\.bom\.aggregate\.name has been set\) and this property is set to DIRECT, the aggregate BDIO file will exclude code location nodes from the top layer of the dependency tree to preserve the correct identification of direct dependencies in the resulting Black Duck BOM\. When this property is set to TRANSITIVE \(the default\), component source information is preserved by including code location nodes at the top of the dependency tree, but all components will appear as TRANSITIVE in the BOM\. SUBPROJECT aggregation mode provides both component source information and correct identification of direct and transitive dependencies by encoding code location nodes as subprojects in the graph\. SUBPROJECT aggregation mode must only be used with Black Duck 2021\.8\.0 or later, and has no effect \(is equivalent to TRANSITIVE mode\) when detect\.bdio2\.enabled is set to false\.



**DEPRECATED: This property is being removed, along with the ability to set the aggregation mode\. In the future, Detect will always operate in SUBPROJECT aggregation mode \(regardless of how it is configured\) to more accurately report the dependency graph\. This property will be removed in 8\.0\.0.**

|Details||
|---|---|
|Added|6\.1\.0|
|Type|AggregateMode|
|Default Value|TRANSITIVE|
|Comma Separated|No|
|Case Sensitive|Yes|
|Acceptable Values|DIRECT, TRANSITIVE, SUBPROJECT|
|Strict|Yes|
    
